@@ -69,6 +69,7 @@ const (
 	color16             = "color16"
 	left                = "left"
 	osc99               = "osc99"
+	osc7                = "osc7"
 	lineChange          = "linechange"
 	consoleTitle        = "title"
 	link                = "link"
@@ -195,6 +196,7 @@ func (ir *ImageRenderer) Init(config string) {
 		color16:             `^(?P<STR>\x1b\[(?P<BC>[349][0-7]|10[0-7]|39)m)`,
 		left:                `^(?P<STR>\x1b\[(\d{1,3})D)`,
 		osc99:               `^(?P<STR>\x1b\]9;9;(.+)\x1b\\)`,
+		osc7:                `^(?P<STR>\x1b\]7;(.+)\x1b\\)`,
 		lineChange:          `^(?P<STR>\x1b\[(\d)[FB])`,
 		consoleTitle:        `^(?P<STR>\x1b\]0;(.+)\007)`,
 		link:                fmt.Sprintf(`^%s`, regex.LINK),
@@ -502,7 +504,7 @@ func (ir *ImageRenderer) shouldPrint() bool {
 		case boldReset, italicReset, underlineReset, overlineReset:
 			ir.style = ""
 			return false
-		case strikethrough, strikethroughReset, left, osc99, lineChange, consoleTitle:
+		case strikethrough, strikethroughReset, left, osc99, osc7, lineChange, consoleTitle:
 			return false
 		case color16:
 			ir.setBase16Color(match[bc])
