@@ -2,8 +2,10 @@ package segments
 
 import (
 	"fmt"
+	"oh-my-posh/environment"
 	"oh-my-posh/properties"
 	"oh-my-posh/regex"
+	"path/filepath"
 	"strconv"
 	"strings"
 
@@ -50,6 +52,7 @@ type Git struct {
 	StashCount    int
 	WorktreeCount int
 	IsWorkTree    bool
+	RepoName      string
 }
 
 const (
@@ -98,6 +101,8 @@ const (
 	GitIcon properties.Property = "git_icon"
 	// UntrackedModes list the optional untracked files mode per repo
 	UntrackedModes properties.Property = "untracked_modes"
+	// IgnoreSubmodules list the optional ignore-submodules mode per repo
+	IgnoreSubmodules properties.Property = "ignore_submodules"
 
 	DETACHED     = "(detached)"
 	BRANCHPREFIX = "ref: refs/heads/"
@@ -105,13 +110,14 @@ const (
 )
 
 func (g *Git) Template() string {
-	return " {{ .HEAD }} {{ .BranchStatus }}{{ if .Working.Changed }} \uF044 {{ .Working.String }}{{ end }}{{ if and (.Staging.Changed) (.Working.Changed) }} |{{ end }}{{ if .Staging.Changed }} \uF046 {{ .Staging.String }}{{ end }}{{ if gt .StashCount 0}} \uF692 {{ .StashCount }}{{ end }}{{ if gt .WorktreeCount 0}} \uf1bb {{ .WorktreeCount }}{{ end }} " // nolint: lll
+	return " {{ .HEAD }} {{ .BranchStatus }}{{ if .Working.Changed }} \uF044 {{ .Working.String }}{{ end }}{{ if and (.Staging.Changed) (.Working.Changed) }} |{{ end }}{{ if .Staging.Changed }} \uF046 {{ .Staging.String }}{{ end }}{{ if gt .StashCount 0}} \uF692 {{ .StashCount }}{{ end }}{{ if gt .WorktreeCount 0}} \uf1bb {{ .WorktreeCount }}{{ end }} " //nolint: lll
 }
 
 func (g *Git) Enabled() bool {
 	if !g.shouldDisplay() {
 		return false
 	}
+	g.RepoName = environment.Base(g.env, g.realFolder)
 	displayStatus := g.props.GetBool(FetchStatus, false)
 	if displayStatus {
 		g.setGitStatus()
@@ -139,63 +145,84 @@ func (g *Git) shouldDisplay() bool {
 	// we must use git.exe and convert paths accordingly
 	// for worktrees, stashes, and path to work
 	g.IsWslSharedPath = g.env.InWSLSharedDrive()
+
 	if !g.env.HasCommand(g.getCommand(GITCOMMAND)) {
 		return false
 	}
+
 	gitdir, err := g.env.HasParentFilePath(".git")
 	if err != nil {
 		return false
 	}
+
 	if g.shouldIgnoreRootRepository(gitdir.ParentFolder) {
 		return false
 	}
 
-	if gitdir.IsDir {
-		g.workingFolder = gitdir.Path
-		g.rootFolder = gitdir.Path
-		// convert the worktree file path to a windows one when in wsl 2 shared folder
-		g.realFolder = strings.TrimSuffix(g.convertToWindowsPath(gitdir.Path), ".git")
-		return true
+	if !gitdir.IsDir {
+		return g.hasWorktree(gitdir)
 	}
-	// handle worktree
+
+	g.workingFolder = gitdir.Path
+	g.rootFolder = gitdir.Path
+	// convert the worktree file path to a windows one when in wsl 2 shared folder
+	g.realFolder = strings.TrimSuffix(g.convertToWindowsPath(gitdir.Path), ".git")
+	return true
+}
+
+func (g *Git) hasWorktree(gitdir *environment.FileInfo) bool {
 	g.rootFolder = gitdir.Path
 	dirPointer := strings.Trim(g.env.FileContent(gitdir.Path), " \r\n")
 	matches := regex.FindNamedRegexMatch(`^gitdir: (?P<dir>.*)$`, dirPointer)
-	if matches != nil && matches["dir"] != "" {
-		// if we open a worktree file in a shared wsl2 folder, we have to convert it back
-		// to the mounted path
-		g.workingFolder = g.convertToLinuxPath(matches["dir"])
+	if matches == nil || matches["dir"] == "" {
+		return false
+	}
+	// if we open a worktree file in a shared wsl2 folder, we have to convert it back
+	// to the mounted path
+	g.workingFolder = g.convertToLinuxPath(matches["dir"])
 
-		// in worktrees, the path looks like this: gitdir: path/.git/worktrees/branch
-		// strips the last .git/worktrees part
-		// :ind+5 = index + /.git
-		ind := strings.LastIndex(g.workingFolder, "/.git/worktrees")
-		if ind > -1 {
-			g.rootFolder = g.workingFolder[:ind+5]
-			g.realFolder = strings.TrimSuffix(g.env.FileContent(g.workingFolder+"/gitdir"), ".git\n")
+	// in worktrees, the path looks like this: gitdir: path/.git/worktrees/branch
+	// strips the last .git/worktrees part
+	// :ind+5 = index + /.git
+	ind := strings.LastIndex(g.workingFolder, "/.git/worktrees")
+	if ind > -1 {
+		gitDir := filepath.Join(g.workingFolder, "gitdir")
+		g.rootFolder = g.workingFolder[:ind+5]
+		g.realFolder = strings.TrimSuffix(g.env.FileContent(gitDir), ".git\n")
+		g.IsWorkTree = true
+		return true
+	}
+	// in submodules, the path looks like this: gitdir: ../.git/modules/test-submodule
+	// we need the parent folder to detect where the real .git folder is
+	ind = strings.LastIndex(g.workingFolder, "/.git/modules")
+	if ind > -1 {
+		g.rootFolder = resolveGitPath(gitdir.ParentFolder, g.workingFolder)
+		// this might be both a worktree and a submodule, where the path would look like
+		// this: path/.git/modules/module/path/worktrees/location. We cannot distinguish
+		// between worktree and a module path containing the word 'worktree,' however.
+		ind = strings.LastIndex(g.rootFolder, "/worktrees/")
+		if ind > -1 && g.env.HasFilesInDir(g.rootFolder, "gitdir") {
+			gitDir := filepath.Join(g.rootFolder, "gitdir")
+			realGitFolder := g.env.FileContent(gitDir)
+			g.realFolder = strings.TrimSuffix(realGitFolder, ".git\n")
+			g.rootFolder = g.rootFolder[:ind]
+			g.workingFolder = g.rootFolder
 			g.IsWorkTree = true
 			return true
 		}
-		// in submodules, the path looks like this: gitdir: ../.git/modules/test-submodule
-		// we need the parent folder to detect where the real .git folder is
-		ind = strings.LastIndex(g.workingFolder, "/.git/modules")
-		if ind > -1 {
-			g.rootFolder = gitdir.ParentFolder + "/" + g.workingFolder
-			g.realFolder = g.rootFolder
-			g.workingFolder = g.rootFolder
-			return true
-		}
+		g.realFolder = g.rootFolder
+		g.workingFolder = g.rootFolder
+		return true
+	}
 
-		// check for separate git folder(--separate-git-dir)
-		// check if the folder contains a HEAD file
-		if g.env.HasFilesInDir(g.workingFolder, "HEAD") {
-			gitFolder := strings.TrimSuffix(g.rootFolder, ".git")
-			g.rootFolder = g.workingFolder
-			g.workingFolder = gitFolder
-			g.realFolder = gitFolder
-			return true
-		}
-		return false
+	// check for separate git folder(--separate-git-dir)
+	// check if the folder contains a HEAD file
+	if g.env.HasFilesInDir(g.workingFolder, "HEAD") {
+		gitFolder := strings.TrimSuffix(g.rootFolder, ".git")
+		g.rootFolder = g.workingFolder
+		g.workingFolder = gitFolder
+		g.realFolder = gitFolder
+		return true
 	}
 	return false
 }
@@ -266,7 +293,12 @@ func (g *Git) setGitStatus() {
 	g.Working = &GitStatus{}
 	g.Staging = &GitStatus{}
 	untrackedMode := g.getUntrackedFilesMode()
-	output := g.getGitCommandOutput("status", untrackedMode, "--branch", "--porcelain=2")
+	args := []string{"status", untrackedMode, "--branch", "--porcelain=2"}
+	ignoreSubmodulesMode := g.getIgnoreSubmodulesMode()
+	if len(ignoreSubmodulesMode) > 0 {
+		args = append(args, ignoreSubmodulesMode)
+	}
+	output := g.getGitCommandOutput(args...)
 	for _, line := range strings.Split(output, "\n") {
 		if strings.HasPrefix(line, HASH) && len(line) >= len(HASH)+7 {
 			g.Hash = line[len(HASH) : len(HASH)+7]
@@ -516,10 +548,25 @@ func (g *Git) getOriginURL(upstream string) string {
 }
 
 func (g *Git) getUntrackedFilesMode() string {
-	mode := "normal"
-	repoModes := g.props.GetKeyValueMap(UntrackedModes, map[string]string{})
+	return g.getSwitchMode(UntrackedModes, "-u", "normal")
+}
+
+func (g *Git) getIgnoreSubmodulesMode() string {
+	return g.getSwitchMode(IgnoreSubmodules, "--ignore-submodules=", "")
+}
+
+func (g *Git) getSwitchMode(property properties.Property, gitSwitch, mode string) string {
+	repoModes := g.props.GetKeyValueMap(property, map[string]string{})
+	// make use of a wildcard for all repo's
+	if val := repoModes["*"]; len(val) != 0 {
+		mode = val
+	}
+	// get the specific repo mode
 	if val := repoModes[g.realFolder]; len(val) != 0 {
 		mode = val
 	}
-	return fmt.Sprintf("-u%s", mode)
+	if len(mode) == 0 {
+		return ""
+	}
+	return fmt.Sprintf("%s%s", gitSwitch, mode)
 }
