@@ -4,6 +4,7 @@ import (
 	"encoding/json"
 	"oh-my-posh/environment"
 	"oh-my-posh/properties"
+	"oh-my-posh/template"
 )
 
 type Wakatime struct {
@@ -34,8 +35,11 @@ func (w *Wakatime) Enabled() bool {
 }
 
 func (w *Wakatime) setAPIData() error {
-	url := w.props.GetString(URL, "")
-	cacheTimeout := w.props.GetInt(CacheTimeout, DefaultCacheTimeout)
+	url, err := w.getURL()
+	if err != nil {
+		return err
+	}
+	cacheTimeout := w.props.GetInt(properties.CacheTimeout, properties.DefaultCacheTimeout)
 	if cacheTimeout > 0 {
 		// check if data stored in cache
 		if val, found := w.env.Cache().Get(url); found {
@@ -47,9 +51,9 @@ func (w *Wakatime) setAPIData() error {
 		}
 	}
 
-	httpTimeout := w.props.GetInt(HTTPTimeout, DefaultHTTPTimeout)
+	httpTimeout := w.props.GetInt(properties.HTTPTimeout, properties.DefaultHTTPTimeout)
 
-	body, err := w.env.HTTPRequest(url, httpTimeout)
+	body, err := w.env.HTTPRequest(url, nil, httpTimeout)
 	if err != nil {
 		return err
 	}
@@ -64,6 +68,16 @@ func (w *Wakatime) setAPIData() error {
 	return nil
 }
 
+func (w *Wakatime) getURL() (string, error) {
+	url := w.props.GetString(URL, "")
+	tmpl := &template.Text{
+		Template: url,
+		Context:  w,
+		Env:      w.env,
+	}
+	return tmpl.Render()
+}
+
 func (w *Wakatime) Init(props properties.Properties, env environment.Environment) {
 	w.props = props
 	w.env = env
