@@ -20,21 +20,21 @@ end
 
 -- Duration functions
 
-local endedit_time
-local last_duration
+local endedit_time = 0
+local last_duration = 0
 local tip
 local tooltip_active = false
 local cached_prompt = {}
 
 local function omp_exe()
-    return [["::OMP::"]]
+    return '"'..::OMP::..'"'
 end
 
 local function omp_config()
-    return [["::CONFIG::"]]
+    return '"'..::CONFIG::..'"'
 end
 
-os.setenv("POSH_THEME", omp_config())
+os.setenv("POSH_THEME", ::CONFIG::)
 
 local function can_async()
     if (clink.version_encoded or 0) >= 10030001 then
@@ -67,7 +67,7 @@ end
 
 local function duration_onbeginedit()
     last_duration = 0
-    if endedit_time then
+    if endedit_time ~= 0 then
         local beginedit_time = os_clock_millis()
         local elapsed = beginedit_time - endedit_time
         if elapsed >= 0 then
@@ -76,8 +76,12 @@ local function duration_onbeginedit()
     end
 end
 
-local function duration_onendedit()
-    endedit_time = os_clock_millis()
+local function duration_onendedit(input)
+    endedit_time = 0
+    -- For an empty command, the execution time should not be evaluated.
+    if string.gsub(input, "^%s*(.-)%s*$", "%1") ~= "" then
+        endedit_time = os_clock_millis()
+    end
 end
 
 -- Prompt functions
@@ -113,7 +117,7 @@ local function set_posh_tooltip(command)
     command = string.gsub(command, '\\+"', '%1%1"')
     command = string.gsub(command, '\\+$', '%1%1')
     command = string.gsub(command, '"', '\\"')
-    local prompt_exe = string.format('%s print tooltip --shell=cmd --config=%s --command="%s"', omp_exe(), omp_config(), command)
+    local prompt_exe = string.format('%s print tooltip --shell=cmd %s --config=%s --command="%s"', omp_exe(), error_level_option(), omp_config(), command)
     local tooltip = run_posh_command(prompt_exe)
     if tooltip ~= "" then
         tooltip_active = true
@@ -188,8 +192,8 @@ local function builtin_modules_onbeginedit()
     duration_onbeginedit()
 end
 
-local function builtin_modules_onendedit()
-    duration_onendedit()
+local function builtin_modules_onendedit(input)
+    duration_onendedit(input)
 end
 
 if clink.onbeginedit ~= nil and clink.onendedit ~= nil then
