@@ -62,12 +62,14 @@ module.exports = {
         "segments/crystal",
         "segments/cf",
         "segments/cftarget",
+        "segments/cmake",
         "segments/dart",
         "segments/dotnet",
         "segments/executiontime",
         "segments/exit",
         "segments/flutter",
         "segments/fossil",
+        "segments/gcp",
         "segments/git",
         "segments/poshgit",
         "segments/golang",
@@ -78,6 +80,7 @@ module.exports = {
         "segments/julia",
         "segments/kotlin",
         "segments/kubectl",
+        "segments/lua",
         "segments/nbgv",
         "segments/nightscout",
         "segments/npm",
@@ -86,6 +89,7 @@ module.exports = {
         "segments/os",
         "segments/owm",
         "segments/path",
+        "segments/perl",
         "segments/php",
         "segments/plastic",
         "segments/project",
@@ -107,6 +111,7 @@ module.exports = {
         "segments/ui5tooling",
         "segments/wakatime",
         "segments/wifi",
+        "segments/withings",
         "segments/winreg",
         "segments/ytm",
       ],
